<?php /*
--------------------------------------------
Custom Post Type
--------------------------------------------
*/
add_action('init', 'carPosts');
function carPosts () {
	register_post_type( 'cars', // Our very own post type
		array( 
			'labels' => array(
				'name' => 'Cars',
				'all_items' => 'All Cars',
				'singular_name' => 'Car',
				'add_new_item' => 'Add Car',
				'edit_item' => 'Edit Car',
				'search_items' => 'Search Cars',
				'view_item' => 'View Car',
				'not_found' => 'No Cars Found',
				'not_found_in_trash' => 'No Cars Found in Trash',
				'menu_name' => 'Cars'
			),
			'public' => true,
			'publicly_queryable' => true,
			'show_ui' => true,
			'has_archive' => true,
			'supports' => array (
				'title',
				'page-attributes',
				'editor',
				'thumbnail',
			),
			'taxonomies' => array(
				'model',
				'make',
				'features',
			),
			'exclude_from_search' => false,
			'_builtin' => false,
			'hierarchical' => false,
			'rewrite' => array("slug" => "cars"),
		)
	);
};

/*
--------------------------------------------
Custom Taxonomy
--------------------------------------------
*/
add_action('init', 'ar_taxonomies');
function ar_taxonomies() { // We want to be able to sort our plugin items by our terms and keep them seperate from pages/posts.
	register_taxonomy( 'Model', 'cars', array(
			'labels' => array(
				'name' => _x('Model', 'taxonomy general name'),
				'singular_name' => 'Model',
				'search_items' => 'Search Model',
				'popular_items' => 'Popular Model',
				'all_items' => 'All Model',
				'parent_item' => __( 'Parent Model' ),
  				'parent_item_colon' => __( 'Parent Model:' ),
				'edit_item' => __( 'Edit Model' ), 
				'update_item' => __( 'Update Model' ),
				'add_new_item' => __( 'Add New Model' ),
				'new_item_name' => __( 'New Model' ),
				'separate_items_with_commas' => __( 'Separate Model with commas' ),
				'add_or_remove_items' => __( 'Add or Remove Model' ),
				'choose_from_most_used' => __( 'Choose from the most used Model' ),
				'menu_name' => __( 'Model' ),
			),
			'hierarchical' => true,
			'show_ui' => true,
			'query_var' => true,
			'rewrite' => array( 'slug' => 'Model' ),
			'public' => true
		)
	);
register_taxonomy( 'Features', 'cars', array(
			'labels' => array(
				'name' => _x('Features', 'taxonomy general name'),
				'singular_name' => 'Features',
				'search_items' => 'Search Features',
				'popular_items' => 'Popular Features',
				'all_items' => 'All Features',
				'parent_item' => __( 'Parent Features' ),
  				'parent_item_colon' => __( 'Parent Features:' ),
				'edit_item' => __( 'Edit Features' ), 
				'update_item' => __( 'Update Features' ),
				'add_new_item' => __( 'Add New Features' ),
				'new_item_name' => __( 'New Features' ),
				'separate_items_with_commas' => __( 'Separate Features with commas' ),
				'add_or_remove_items' => __( 'Add or Remove Features' ),
				'choose_from_most_used' => __( 'Choose from the most used Features' ),
				'menu_name' => __( 'Features' ),
			),
			'hierarchical' => true,
			'show_ui' => true,
			'query_var' => true,
			'rewrite' => array( 'slug' => 'Features' ),
			'public' => true
		)
	);
}
/*
--------------------------------------------
Extra Post Columns | I never felt the default
all posts page in the back end showed enough 
info so we're adding in a bit extra.
--------------------------------------------
*/
add_filter('manage_edit-listing_columns', 'add_new_listing_columns'); 
add_action('manage_listing_posts_custom_column', 'manage_listing_columns', 10, 2);

function add_new_listing_columns($gallery_columns) { //Declare the columns we want
	$new_columns['cb'] = '<input type="checkbox" />';

	$new_columns['id'] = __('ID'); // I hate having to go the the address bar of the edit post page to get the ID, this is easier.
	$new_columns['title'] = __('Name', 'column name');

	$new_columns['listing'] = __('Listing Type', 'column name'); // I know it's called Category, but it's not the same as the post category, we want ours seperate
	$new_columns['realtor'] = __('Realtor', 'column name');
	$new_columns['date'] = __('Date', 'column name');

	return $new_columns;
}
function manage_listing_columns($column_name, $id) { // And what we want the columns to hold
	global $wpdb;
	switch ($column_name) {
		case 'id':
			echo $id;
				break;
	
		case 'listing':
			$tags = get_the_terms($post->ID, 'listing_type'); //listing_type is the first custom taxonomy slug
            if ( !empty( $tags ) ) {
                $out = array();
                foreach ( $tags as $c )
                    $out[] = '<a href="edit.php?post_type=listing&listing_type='.$c->slug.'">' . esc_html(sanitize_term_field('name', $c->name, $c->term_id, 'listing_type', 'display')) . '</a>';
                echo join( ', ', $out );
            } else {
                _e('Not Specified.');  //No Taxonomy term defined
            } 
			break;
		case 'realtor':
			echo get_post_meta( get_the_ID(), 'ar_realtor', true);
			break;
		default:
			break;
	} // end switch
	echo '
		<style type="text/css">
			.column-id {
				width: 55px;
			}
		</style>
	';
}

/*
--------------------------------------------
Create a new taxonomy item everytime a new 
post is created in the realtor post type
--------------------------------------------
*/
function realtorposttax($post_id) {
    global $meta_box,  $post; 
    //Check autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }
 
    //Check permissions
    if ('page' == $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id)) {
            return $post_id;
        }
    } elseif (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }
    
    foreach ($meta_box[$post->post_type]['fields'] as $field) {
        $old = get_post_meta($post_id, $field['id'], true);
        $new = $_POST[$field['id']];
        
        if ($new && $new != $old) {
            update_post_meta($post_id, $field['id'], $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id, $field['id'], $old);
        }
    }
}
 
add_action('save_post', 'listing_save_data');